@@ -65,17 +65,6 @@ PyObject* pyalpm_initialize(PyTypeObject *subtype, PyObject *args, PyObject *kwa
   }
 }
 
-PyObject* pyalpm_release(PyObject *self, PyObject *args)
-{
-  AlpmHandle *pyhandle;
-  if(!PyArg_ParseTuple(args, "O!", &AlpmHandleType, &pyhandle))
-    return NULL;
-
-  alpm_release(pyhandle->c_data);
-  pyhandle->c_data = NULL;
-  Py_RETURN_NONE;
-}
-
 /* Database getters/setters */
 
 static PyObject* pyalpm_get_localdb(PyObject *self, PyObject *dummy) {
@@ -261,11 +250,7 @@ struct PyGetSetDef pyalpm_handle_getset[] = {
     (getter)option_get_usesyslog_alpm,
     (setter)option_set_usesyslog_alpm,
     "use syslog (an integer, 0 = False, 1 = True)", NULL } ,
-  { "deltaratio",
-    (getter)option_get_deltaratio_alpm,
-    (setter)option_set_deltaratio_alpm,
-    "set deltaratio (a float). Deltas are enabled if this is nonzero.", NULL } ,
-  { "checkspace",
+ { "checkspace",
     (getter)option_get_checkspace_alpm,
     (setter)option_set_checkspace_alpm,
     "check disk space before transactions (an integer, 0 = False, 1 = True)", NULL } ,
@@ -342,7 +327,7 @@ static PyMethodDef pyalpm_handle_methods[] = {
     "Arguments:\n"
     "  nodeps, force, nosave, nodepversion, cascade, recurse,\n"
     "  dbonly, alldeps, downloadonly, noscriptlet, noconflicts,\n"
-    "  needed, allexplicit, inneeded, recurseall, nolock\n"
+    "  needed, allexplicit, unneeded, recurseall, nolock\n"
     "    -- the transaction options (booleans)\n"
   },
 
@@ -377,6 +362,16 @@ static PyMethodDef pyalpm_handle_methods[] = {
   {NULL, NULL, 0, NULL},
 };
 
+static void pyalpm_dealloc(PyObject* self) {
+  alpm_handle_t *handle = ALPM_HANDLE(self);
+  int ret = alpm_release(handle);
+  if (ret == -1) {
+    PyErr_Format(alpm_error, "unable to release alpm handle");
+  }
+  handle = NULL;
+  Py_TYPE(self)->tp_free((PyObject *)self);
+}
+
 PyTypeObject AlpmHandleType = {
   PyVarObject_HEAD_INIT(NULL, 0)
   "alpm.Handle",       /*tp_name*/
@@ -387,6 +382,7 @@ PyTypeObject AlpmHandleType = {
   .tp_methods = pyalpm_handle_methods,
   .tp_getset = pyalpm_handle_getset,
   .tp_new = pyalpm_initialize,
+  .tp_dealloc = (destructor) pyalpm_dealloc,
 };
 
 /** Initializes Handle class in module */
