@@ -20,7 +20,6 @@
 
 #include "pyalpm.h"
 #include "util.h"
-#include "handle.h"
 #include "package.h"
 #include "db.h"
 
@@ -88,7 +87,7 @@ static PyMethodDef methods[] = {
     "args: a list of packages, a dependency string\n"
     "returns: a Package object or None" },
 
-  {"sync_newversion", pyalpm_sync_newversion, METH_VARARGS,
+  {"sync_newversion", pyalpm_sync_get_new_version, METH_VARARGS,
     "finds an available upgrade for a package in a list of databases\n"
     "args: a package, a list of databases\n"
     "returns: an upgrade candidate or None" },
@@ -101,13 +100,32 @@ static PyMethodDef methods[] = {
   {NULL, NULL, 0, NULL}
 };
 
+static int pyalpm_clear(PyObject *m)
+{
+  PyObject *dict = PyModule_GetDict(m);
+  if (dict == NULL) {
+    return 0;
+  }
+
+  PyObject *error = PyDict_GetItemString(dict, "error");
+  if (error == NULL) {
+    return 0;
+  }
+
+  Py_DECREF(error);
+
+  return 0;
+}
+
 static struct PyModuleDef pyalpm_def = {
   PyModuleDef_HEAD_INIT,
   "alpm",
   "This module wraps the libalpm library",
   -1,
   methods,
-  NULL, NULL, NULL, NULL,
+  NULL, NULL,
+  pyalpm_clear,
+  NULL,
 };
 
 PyMODINIT_FUNC PyInit_pyalpm(void)
