@@ -20,6 +20,7 @@
  *
  */
 
+#include <pyconfig.h>
 #include <string.h>
 #include <alpm.h>
 #include <Python.h>
@@ -105,14 +106,6 @@ void pyalpm_eventcb(alpm_event_t *event) {
       break;
     case ALPM_EVENT_LOAD_START:
     case ALPM_EVENT_LOAD_DONE:
-    case ALPM_EVENT_DELTA_INTEGRITY_START:
-    case ALPM_EVENT_DELTA_INTEGRITY_DONE:
-    case ALPM_EVENT_DELTA_PATCHES_START:
-    case ALPM_EVENT_DELTA_PATCHES_DONE:
-    case ALPM_EVENT_DELTA_PATCH_START:
-      /* info here */
-    case ALPM_EVENT_DELTA_PATCH_DONE:
-    case ALPM_EVENT_DELTA_PATCH_FAILED:
     case ALPM_EVENT_SCRIPTLET_INFO:
       /* info here */
     case ALPM_EVENT_RETRIEVE_START:
@@ -192,14 +185,6 @@ static PyObject* pyobject_from_pmdepmissing(void *item) {
   return result;
 }
 
-static PyObject* pyobject_from_pmconflict(void *item) {
-  alpm_conflict_t* conflict = (alpm_conflict_t*)item;
-  return Py_BuildValue("(sss)",
-      conflict->package1,
-      conflict->package2,
-      conflict->reason);
-}
-
 static PyObject* pyobject_from_pmfileconflict(void *item) {
   alpm_fileconflict_t* conflict = (alpm_fileconflict_t*)item;
   const char *target = conflict->target;
@@ -299,7 +284,7 @@ PyObject* pyalpm_trans_init(PyObject *self, PyObject *args, PyObject *kwargs) {
 
   /* check all arguments */
   if (!PyArg_ParseTupleAndKeywords(args, kwargs,
-        "|bbbbbbbbbbbbbbbbOOO", (char**)keywords,
+        "|bbbbbbbbbbbbbbbb", (char**)keywords,
         INDEX_FLAGS(&flags))) {
     return NULL;
   }
@@ -359,9 +344,6 @@ static PyObject* pyalpm_trans_commit(PyObject *self, PyObject *args) {
     case ALPM_ERR_PKG_INVALID:
     case ALPM_ERR_PKG_INVALID_CHECKSUM:
     case ALPM_ERR_PKG_INVALID_SIG:
-    case ALPM_ERR_DLT_INVALID:
-      err_info = alpmlist_to_pylist(data, pyobject_from_string);
-      break;
     default:
       break;
   }
